@@ -27,7 +27,9 @@ from PIL import Image
 
 from tfrecorder import beam_image
 from tfrecorder import test_utils
-from tfrecorder import schema
+from tfrecorder import input_schema
+
+RANDOM_SEED = 42
 
 
 class BeamImageTests(unittest.TestCase):
@@ -36,7 +38,8 @@ class BeamImageTests(unittest.TestCase):
   def setUp(self):
     self.pipeline = test_utils.get_test_pipeline()
     self.df = test_utils.get_test_df()
-    self.image_file = 'tfrecorder/test_data/images/cat/cat-640x853-1.jpg'
+    self.image_file = self.df.image_uri.sample(
+        random_state=RANDOM_SEED).values[0]
 
   def test_load(self):
     """Tests the image loading function."""
@@ -46,7 +49,7 @@ class BeamImageTests(unittest.TestCase):
   def test_file_not_found_load(self):
     """Test loading an image that doesn't exist."""
     with self.assertRaises(OSError):
-      _ = beam_image.load('tfrecorder/test_data/images/cat/food.jpg')
+      _ = beam_image.load('/some/image/dir/food.jpg')
 
   def test_mode_to_channel(self):
     """Tests `mode_to_channel`."""
@@ -83,10 +86,8 @@ class BeamImageTests(unittest.TestCase):
 
     with self.pipeline as p:
 
-      converter = schema.get_tft_coder(['split', 'image_uri', 'label'],
-                                       schema.image_csv_schema)
-
-
+      schema = input_schema.IMAGE_CSV_SCHEMA
+      converter = schema.get_input_coder()
       extract_images_fn = beam_image.ExtractImagesDoFn('image_uri')
 
       data = (
