@@ -26,7 +26,7 @@ from PIL import Image
 from apache_beam.testing import test_pipeline
 import pandas as pd
 
-from tfrecorder import schema
+from tfrecorder import input_schema
 
 
 TEST_DIR = 'tfrecorder/test_data'
@@ -44,12 +44,12 @@ def get_test_data() -> Dict[str, List[Any]]:
   return get_test_df().to_dict(orient='list')
 
 
-def get_raw_feature_df() -> pd.DataFrame:
-  """Returns test dataframe having raw feature spec schema."""
+def get_pre_tft_feature_df() -> pd.DataFrame:
+  """Returns test dataframe having pre-TF Transform feature spec schema."""
 
   df = get_test_df()
-  my_raw_schema = schema.get_raw_schema_map(schema.image_csv_schema)
-  image_key = schema.get_key(schema.ImageUriType, schema.image_csv_schema)
+  schema = input_schema.Schema(input_schema.image_csv_schema_map)
+  image_key = schema.image_uri_key
   df.drop([image_key], axis=1, inplace=True)
   df['image_name'] = 'image_name'
   df['image'] = 'image'
@@ -59,8 +59,7 @@ def get_raw_feature_df() -> pd.DataFrame:
   df['image_height'] = '48'
   df['image_width'] = '48'
   df['image_channels'] = '3'
-  df = df[my_raw_schema.keys()]
-
+  df = df[schema.pre_tft_schema_map.keys()]
   return df
 
 
